package com.example.actionbar_pull_to_refresh.app;

import android.os.Handler;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;


import uk.co.senab.actionbarpulltorefresh.library.ActionBarPullToRefresh;
import uk.co.senab.actionbarpulltorefresh.library.PullToRefreshLayout;
import uk.co.senab.actionbarpulltorefresh.library.listeners.OnRefreshListener;
import uk.co.senab.actionbarpulltorefresh.library.viewdelegates.ViewDelegate;


/** Demo of ActionBar-Pull-to-Refresh
 *  with empty view handling.
 */
public class MainActivity extends ActionBarActivity implements
        OnRefreshListener {

    public static final String[] mItems = new String[] {"a", "b", "c", "d", "e", "f", "g", "h"};


    private ListView mList;
    private ListViewHelper mListHelper;
//    private ButterKnifeListViewHelper mListHelper;
    private HelloWorldAdapter mAdapter;
    private Handler mHandler = new Handler();

    private PullToRefreshLayout mPullToRefreshLayout;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mList = (ListView) findViewById(android.R.id.list);
        mListHelper = new ListViewHelper(findViewById(R.id.main));
//        mListHelper = new ButterKnifeListViewHelper(findViewById(R.id.main));
        mListHelper.showLoading();
        mHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                mListHelper.showEmpty();
            }
        }, 3000);

        mAdapter = new HelloWorldAdapter(this);
        mList.setAdapter(mAdapter);

        mPullToRefreshLayout = new PullToRefreshLayout(this);

        ActionBarPullToRefresh.from(this)
                .insertLayoutInto((ViewGroup) getWindow().getDecorView())
                .theseChildrenArePullable(android.R.id.list, android.R.id.empty)
                .listener(this)
                // hack to make it work with empty view
                .useViewDelegate(View.class, new ViewDelegate() {
                    @Override
                    public boolean isReadyForPull(View view, float v, float v2) {
                        return Boolean.TRUE;
                    }
                })
                .setup(mPullToRefreshLayout);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }


    @Override
    public void onRefreshStarted(View view) {
        mHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                mAdapter.setData(mItems);
                mPullToRefreshLayout.setRefreshComplete();
            }
        }, 3000);
    }
}
